API Reference
=============

System
------

.. autoclass:: autoreduce.system.System
   :members:
   :undoc-members:
   :show-inheritance:

Reduce
------

.. autoclass:: autoreduce.model_reduction.Reduce
   :members:
   :undoc-members:
   :show-inheritance:

Utils
-----

.. automodule:: autoreduce.utils
   :members:
   :undoc-members:
   :show-inheritance:

Converters
----------

.. automodule:: autoreduce.converters
   :members:
   :undoc-members:
   :show-inheritance:
